package com.example.popularmovies

import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import androidx.compose.Composable
import androidx.ui.core.Alignment
import androidx.ui.core.ContentScale
import androidx.ui.core.Modifier
import androidx.ui.core.setContent
import androidx.ui.foundation.AdapterList
import androidx.ui.foundation.Box
import androidx.ui.foundation.Image
import androidx.ui.foundation.Text
import androidx.ui.foundation.shape.corner.RoundedCornerShape
import androidx.ui.layout.*
import androidx.ui.material.Card
import androidx.ui.material.MaterialTheme
import androidx.ui.material.TopAppBar
import androidx.ui.res.imageResource
import androidx.ui.text.TextStyle
import androidx.ui.text.style.TextOverflow
import androidx.ui.tooling.preview.Preview
import androidx.ui.unit.dp
import com.example.popularmovies.data.Movie
import com.example.popularmovies.data.MovieData
import com.example.popularmovies.ui.PopularMoviesTheme

class MainActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            PopularMoviesTheme {
                PopularMoviesMainPage()
            }
        }
    }
}

@Preview(showBackground = true)
@Composable
fun PopularMoviesMainPage() {
    Column {
        TopAppBar(title = { Text(text = "Popular Movies") })
        AdapterList(data = MovieData.list) {
            PopularMoviesListItem(it)
        }
    }
}

@Composable
fun PopularMoviesListItem(movie: Movie) {
    Card(
            shape = RoundedCornerShape(8.dp),
            modifier = Modifier
                    .padding(all = 16.dp)
                    .fillMaxWidth()
                    .height(height = 375.dp)
    ) {

        Column {
            Image(
                    asset = imageResource(id = movie.image),
                    contentScale = ContentScale.FillWidth,
                    modifier = Modifier.preferredHeight(height = 200.dp),
                    alignment = Alignment.TopCenter
            )
            Text(
                    text = movie.title,
                    modifier = Modifier.padding(all = 8.dp),
                    style = MaterialTheme.typography.h6
            )
            Row(
                    modifier = Modifier.padding(all = 8.dp).fillMaxWidth(),
                    horizontalArrangement = Arrangement.SpaceBetween
            ) {
                Text(
                        text = "Release Date: ${movie.releaseDate}",
                        style = MaterialTheme.typography.subtitle2
                )
                Text(
                        text = "Vote: ${movie.voteAverage}/10",
                        style = MaterialTheme.typography.subtitle2
                )
            }
            Text(
                    text = movie.overview,
                    modifier = Modifier.padding(all = 8.dp),
                    maxLines = 5,
                    overflow = TextOverflow.Ellipsis,
                    style = MaterialTheme.typography.caption
            )
        }
    }

}